Class AttachmentConstants

java.lang.Object
com.networknt.httpstring.AttachmentConstants

public class AttachmentConstants extends Object
This class allows the definition of attachment keys shared by multiple modules and thus eliminates dependencies between them
Author:
ddobrin
  • Field Details

    • AUDIT_INFO

      public static final io.undertow.util.AttachmentKey<Map<String,Object>> AUDIT_INFO
    • REQUEST_BODY

      public static final io.undertow.util.AttachmentKey<Object> REQUEST_BODY
    • REQUEST_BODY_STRING

      public static final io.undertow.util.AttachmentKey<String> REQUEST_BODY_STRING
    • RESPONSE_BODY

      public static final io.undertow.util.AttachmentKey<Object> RESPONSE_BODY
    • MDC_CONTEXT

      public static final io.undertow.util.AttachmentKey<Map<String,String>> MDC_CONTEXT
    • RESPONSE_BODY_STRING

      public static final io.undertow.util.AttachmentKey<String> RESPONSE_BODY_STRING
    • BUFFERED_RESPONSE_DATA_KEY

      public static final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> BUFFERED_RESPONSE_DATA_KEY
    • BUFFERED_REQUEST_DATA_KEY

      public static final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> BUFFERED_REQUEST_DATA_KEY
    • DOWNSTREAM_METRICS_NAME

      public static final io.undertow.util.AttachmentKey<String> DOWNSTREAM_METRICS_NAME
    • DOWNSTREAM_METRICS_START

      public static final io.undertow.util.AttachmentKey<Long> DOWNSTREAM_METRICS_START
    • METRICS_HANDLER

      public static final io.undertow.util.AttachmentKey<Object> METRICS_HANDLER
    • RESPONSE_CACHE

      public static final io.undertow.util.AttachmentKey<CacheTask> RESPONSE_CACHE
  • Constructor Details

    • AttachmentConstants

      public AttachmentConstants()