Package com.networknt.httpstring


package com.networknt.httpstring
  • Classes
    Class
    Description
    This class allows the definition of attachment keys shared by multiple modules and thus eliminates dependencies between them
     
    HttpString Constants shared by all light-4j components.