Package com.networknt.httpstring
Class AttachmentConstants
java.lang.Object
com.networknt.httpstring.AttachmentConstants
This class allows the definition of attachment keys shared by multiple modules and thus eliminates dependencies between them
- Author:
- ddobrin
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> static final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> static final io.undertow.util.AttachmentKey<String> static final io.undertow.util.AttachmentKey<Long> static final io.undertow.util.AttachmentKey<Object> static final io.undertow.util.AttachmentKey<Object> static final io.undertow.util.AttachmentKey<String> static final io.undertow.util.AttachmentKey<Object> static final io.undertow.util.AttachmentKey<String> static final io.undertow.util.AttachmentKey<CacheTask> -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
AUDIT_INFO
-
REQUEST_BODY
-
REQUEST_BODY_STRING
-
RESPONSE_BODY
-
MDC_CONTEXT
-
RESPONSE_BODY_STRING
-
BUFFERED_RESPONSE_DATA_KEY
public static final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> BUFFERED_RESPONSE_DATA_KEY -
BUFFERED_REQUEST_DATA_KEY
public static final io.undertow.util.AttachmentKey<io.undertow.connector.PooledByteBuffer[]> BUFFERED_REQUEST_DATA_KEY -
DOWNSTREAM_METRICS_NAME
-
DOWNSTREAM_METRICS_START
-
METRICS_HANDLER
-
RESPONSE_CACHE
-
-
Constructor Details
-
AttachmentConstants
public AttachmentConstants()
-